* project: "The labour market and poverty impacts of Covid-19 in South Africa" (15 July 2020 Version)
* authors: Ronak Jain - rjain@g.harvard.edu, Joshua Budlender - jbudlender@umass.edu, Rocco Zizzamia - rocco.zizzamia@qeh.ox.ac.uk & Ihsaan Bassier - ibassier@umass.edu (randomised author order).
* link: https://cramsurvey.org/wp-content/uploads/2020/07/Jain-The-labour-market-and-poverty-impacts.pdf
********************************************************************************

* this file prepares a dataset of NIDS w5 variables which are used in our LASSO regressions

* due to our original NIDS-CRAM report being produced under tremendous time pressure, this code draws heavily from some of the authors' prior work using NIDS wave 5. Given the time pressures involved, the aim of those code was to quickly generate NIDS wave 5 variables, even if messy. As such:
*==* many extraneous variables are created not needed for the LASSO
*==* the recoding of missing values needed for the LASSO creates noise in some subsequently created variables
*==* NIDS proxy respondents are dropped
*==* NIDS occupation and sector codes are not fully merged together
* These issues have been updated in our current work, which also grabs *substantially* more original wave 5 variables.
* Results are qualitatively unchanged between the old and new versions. For reproducibility of our NIDS-CRAM report this is the old version of the LASSO variables creation.

* this file last updated on 21 July 2020
********************************************************************************
********************************************************************************

clear all
set varabbrev off
set more off

cd ""		// set current directory to main data folder
 
****************************************************************
*DATA SETUP 
****************************************************************


use "Crossection_w5", clear


rename sample sample_w5
rename w5_* *

gen fwgt = round(wgt)

// drop proxy questionnaires 
drop if quest_typ==3

*Employment types
*** Type of employment
	recode em1 em2 ems emsoth emc emp emh (-9/-2=.) (1=1) (2=0)
	gen empltype=.
	replace empltype=0 if empl_stat==0 | empl_stat==1 | empl_stat==2 // replacing these as zero for the unemployed 
	replace empltype=1 if em1==1 & empltype==.
	replace empltype=2 if ems==1 & empltype==.
	replace empltype=3 if emc==1 & empltype==.
	replace empltype=4 if emp==1 & empltype==.
	replace empltype=3 if emh==1 & empltype==. // Note: help others is small group (<2%) --> group together with casual
	lab def empltype 0 "Not employed" 1 "Employee" 2 "Self-employed" 3 "Casual/help others" 4 "Subsistence" // added zero category 
	lab val empltype empltype
	lab var empltype "Type of employment"
	tab empltype, gen(empltype)
	
*** Employment characteristics
	recode em1contr (1=1 "Yes") (2=0 "No") (-9/-2=.), gen(written)	
	lab var written "Written employment agreement"
	recode em1dedmed (1=1 "Yes") (2=0 "No") (-9/-2=.), gen(dedmed)	
	lab var dedmed "Medical aid deduction from salary"
	recode em1dedpen (1=1 "Yes") (2=0 "No") (-9/-2=.), gen(dedpen)	
	lab var dedpen "Pension/Provident fund deduction from salary"
	recode emstax (1=1) (2=0) (-9/-2=.), gen(bsnsstax)
	lab var bsnsstax "Registration of business for income tax &/or VAT"
	
	// creating another category for the unemployed/NEA in these vars
	replace written = 2 if empl_stat==0 |  empl_stat==1 | empl_stat==2
	replace dedmed = 2 if empl_stat==0 | empl_stat==1 |  empl_stat==2
	replace dedpen = 2 if empl_stat==0 | empl_stat==1 | empl_stat==2
	replace bsnsstax = 2 if empl_stat==0 | empl_stat==1 | empl_stat==2

*** Employment status = inactive unempl_broad unempl_strict employed
	ren empl_stat emplstat
	recode emplstat (-9/-2=.)
	tab emplstat, gen(emplstat) 	
	
*** Area
	replace geo2001=. if geo2001<0
	replace geo2011=. if geo2011<0
	tab geo2011, gen (area)

*** Gender
	replace gen=. if gen <0
	
* added recoding:
recode em1deduif (-9/-1=.)
replace em1deduif=3 if emplstat==0 | emplstat==1 | emplstat==2

//Inflating from March 2017 to Feb 2020
scalar base=115.2 														//Set scalar to base month - Feb 2020
gen deflator=.

replace deflator=base/100.6 if h_intrv_m==1 & h_intrv_y==2017
replace deflator=base/101.7 if h_intrv_m==2 & h_intrv_y==2017
replace deflator=base/102.3 if h_intrv_m==3 & h_intrv_y==2017
replace deflator=base/102.4 if h_intrv_m==4 & h_intrv_y==2017
replace deflator=base/102.7 if h_intrv_m==5 & h_intrv_y==2017
replace deflator=base/102.9 if h_intrv_m==6 & h_intrv_y==2017
replace deflator=base/103.2 if h_intrv_m==7 & h_intrv_y==2017
replace deflator=base/103.3 if h_intrv_m==8 & h_intrv_y==2017
replace deflator=base/103.8 if h_intrv_m==9 & h_intrv_y==2017
replace deflator=base/104.1 if h_intrv_m==10 & h_intrv_y==2017
replace deflator=base/104.2 if h_intrv_m==11 & h_intrv_y==2017
replace deflator=base/104.7 if h_intrv_m==12 & h_intrv_y==2017

replace deflator=base/103 if h_intrv_m==. & h_outcome==1

lab var deflator "Wave 5 deflator"


foreach var in hhincome expenditure fwag hhgovt incdis_v  incchld_v incfos_v inccare_v incaid_v incgovpen_v fwag cwag swag hhwage {   
replace `var' = `var'*deflator
}   

foreach var in hhincome expenditure {
gen `var'_pc = (`var' / hhsizer)
		assert `var'_pc >= 1	
}

cap drop totwage
egen totwage= rsum(fwag cwag swag)
replace totwage =0 if emplstat !=3


****************************************************************
*INTERVENTION GROUPS
****************************************************************


//Define informal employment
*Formal employment 
gen formal=.
replace formal=1 if empltype==1 & (written==1 | dedmed==1 | dedpen==1)
replace formal=0 if empltype==1 & (written==0 & dedmed==0 & dedpen==0)
replace formal=1 if empltype==2 & bsnsstax==1
replace formal=0 if empltype==2 & bsnsstax==0
replace formal=0 if empltype==3 | empltype==4
replace formal=2 if emplstat==0 | emplstat==1 |  emplstat==2 // replacing these as 2 for the unemployed 
lab var formal "Formal employment"	

g informal= formal==0 if formal!=.


//identifying those recieving no grants
gen nogrant = 0 if incdis ==1 | incchld ==1 |  incfos ==1 |  inccare ==1 |  incgovpen ==1 
replace nogrant = 1 if (incdis ==2 | incdis == .) & (incchld ==2 | incchld ==.) & (incfos ==2 | incchld ==.) & (inccare ==2 | inccare ==.) & (incgovpen ==2 | incgovpen ==.)

foreach var in incdis incchld incfos inccare incgovpen {
	replace `var' = . if `var'<0 
}

gen nograntfix = 0 if incdis ==1 | incchld ==1 |  incfos ==1 |  inccare ==1 |  incgovpen ==1 
replace nograntfix = 1 if (incdis ==2 | incdis == .) & (incchld ==2 | incchld ==.) & (incfos ==2 | incfos ==.) & (inccare ==2 | inccare ==.) & (incgovpen ==2 | incgovpen ==.)


//GROUPS
global age = "(best_age_yrs >=21 & best_age_yrs < 60 & best_age_yrs !=.)" 

*GROUP 1 - policy-reach-all
gen grp1 = 0 
replace grp1 = 1 if nogrant == 1 & formal !=1 & em1deduif != 1 & $age
bys hhid: egen hhgrp1= max(grp1)

gen grp1fix = 0 
replace grp1fix = 1 if nograntfix == 1 & formal !=1 & em1deduif != 1 & $age
bys hhid: egen hhgrp1fix= max(grp1fix)

*GROUP 2 - policy-reach-workers
gen grp2 = 0 
replace grp2 = 1 if nogrant == 1 & formal ==0 & em1deduif != 1 & emplstat == 3 & $age
bys hhid: egen hhgrp2= max(grp2)

*GROUP 3 - all vulnerable workers 
gen grp3 = 0 
replace grp3 = 1 if formal ==0 & em1deduif != 1 & emplstat == 3 & $age
bys hhid: egen hhgrp3= max(grp3)


*ALT AGES
foreach agelb of numlist 18 25 {
	gen grp1_`agelb' = 0 
	replace grp1_`agelb' = 1 if nogrant == 1 & formal !=1 & em1deduif != 1 & (best_age_yrs >=`agelb' & best_age_yrs < 60 & best_age_yrs !=.)
	bys hhid: egen hhgrp1_`agelb'= max(grp1_`agelb')

	gen grp2_`agelb' = 0 
	replace grp2_`agelb' = 1 if nogrant == 1 & formal ==0 & em1deduif != 1 & emplstat == 3 & (best_age_yrs >=`agelb' & best_age_yrs < 60 & best_age_yrs !=.)
	bys hhid: egen hhgrp2_`agelb'= max(grp2_`agelb')

	gen grp3_`agelb' = 0 
	replace grp3_`agelb' = 1 if formal ==0 & em1deduif != 1 & emplstat == 3 & (best_age_yrs >=`agelb' & best_age_yrs < 60 & best_age_yrs !=.)
	bys hhid: egen hhgrp3_`agelb'= max(grp3_`agelb')
}

g all= 1
egen hhtag= tag(hhid)
ren area2 urban
g female= gen==2 if gen!=.


//CHILD GRANTS VARS 
gen csg= incchld==1
bys hhid: egen hhcsg= max(csg)
assert !mi(hhcsg)	

g csg_income= incchld_v if incchld_v>=0 
bys hhid: egen hhcsg_income = total(csg_income)		
assert !mi(hhcsg_income) 

g csg_children= 1 if inrange(hhcsg_income, 0, 630)
replace csg_children= 2 if inrange(hhcsg_income, 630, 1050)
replace csg_children= 3 if inrange(hhcsg_income, 1050, 1470)
replace csg_children= 4 if inrange(hhcsg_income, 1470, 1890)
replace csg_children= 5 if inrange(hhcsg_income, 1890, 2310)			
replace csg_children= 6 if hhcsg_income>2310 & hhcsg_income!=.
replace csg_children= 0 if hhcsg_income==0


bys hhid: egen hhcsg_children= max(csg_children)


foreach num of numlist 250 300 375 500 {
	g dhhcsg_inc`num'= hhcsg_children*`num'
	assert !mi(dhhcsg_inc`num')
	
	g dcsg_inc`num'_one= hhcsg*`num' if csg_income!=.		
	replace dcsg_inc`num'_one= 0 if dcsg_inc`num'_one==.
}




//PENSION GRANTS
*https://www.gov.za/services/social-benefits-retirement-and-old-age/old-age-pension
gen oap= incgovpen==1
bys hhid: egen hhoap= max(oap)
assert !mi(hhoap)	

*Interventions: 250, 500
g oap_income= incgovpen_v if incgovpen_v>=0 
foreach num of numlist 250 500 {
	g doap_inc`num'= `num' if oap_income!=.					
	replace doap_inc`num'= 0 if doap_inc`num'==.
	bys hhid: egen dhhoap_inc`num'= total(doap_inc`num')
	assert !mi(dhhoap_inc`num')		
}


****************************************************************
*HOUSEHOLD and HOUSEHOLD MEMBER VARS
****************************************************************


//Number per household
*More than one recipient per household
foreach var in grp1 grp2 grp3  { //grp4 RJ
	bys hhid: egen hhtot_`var' = total(`var')
	g `var'_many= hhtot_`var'>1 & hhtot_`var'!=.
}
assert !mi(hhcsg_children)
gen csg_many = hhcsg_children>1


//Informal worker households and earnings
foreach var in informal  { 
	cap drop temp*
	*At least one informal worker
	bys hhid: egen temp= max(`var') if `var'!=.
	bys hhid: egen hh`var'= mean(temp)
	replace hh`var'= 0 if hh`var'==.

	*HH earnings of informal workers
	bys hhid: egen temp2= total(totwage) if `var'==1
	bys hhid: egen hh`var'_income= min(temp2)
	replace hh`var'_income= 0 if hh`var'_income==.
}


//HH Decile vars
gen hhincomepc= hhincome / hhsizer
xtile hhincpc_decile = hhincomepc [aw=wgt], nq(10)

foreach num of numlist 250 375 500 {	
	g dgrp1_inc`num'= `num' if grp1 == 1				
	replace dgrp1_inc`num'= 0 if dgrp1_inc`num'==.
	bys hhid: egen dhhgrp1_inc`num'= total(dgrp1_inc`num')
	assert !mi(dhhgrp1_inc`num')		
}

foreach var in grp1 oap {
	bys hhid: egen numv`var'= total(`var')
}
	// do not do CSG version, as that will be number of adult recipients of CSG. of course this is legit, but may be confusing lower down

foreach var in grp1 oap {
	assert `var'!=.
	assert hh`var'!=.
	assert numv`var'!=.
}

foreach var of varlist dhh* {
	assert !mi(`var')
}

assert !mi(hhinformal_income)
assert !mi(hhincome)
assert !mi(hhincomepc)


****************************************************************
*VULNERABILITY VARS
****************************************************************

sum asacc* dtstvl
tab dtstvl asacc if best_age_yrs>=18 [fw=fwgt], mi

*800,000 have a savings club/stokvel but no bankaccount
*Only 5m missing bank account, also all missing savings 
tab dtstvl asacc if best_age_yrs>=18 & quest_typ == 1 [fw=fwgt], mi

assert !mi(asacc_v) if asacc == 1 & quest_typ == 1		

replace asacc_v= . if inlist(asacc_v, -9, -8, -5, -3)
replace asacc_v= 0 if asacc_brac1==2
replace asacc_v= 250 if asacc_brac1==1 & asacc_brac2==3
replace asacc_v= 500 if asacc_brac2==2
replace asacc_v= 2500 if asacc_brac2==1 & asacc_brac3==3
replace asacc_v= 5000 if asacc_brac3==2
replace asacc_v= 25000 if asacc_brac3==1 & asacc_brac4==3
replace asacc_v= 50000 if asacc_brac4==2
replace asacc_v= 75000 if asacc_brac4==1 & asacc_brac5==3
replace asacc_v= 100000 if asacc_brac5==2 | asacc_brac5==1


g bankacc= asacc==1 if best_age_yrs>=18 

//Household level variables
bys hhid: egen hhbankacc= max(bankacc)
replace hhbankacc= 0 if hhbankacc==.

g bankbal= 0	
replace bankbal= asacc_v if asacc_v !=.
bys hhid: egen hhbankbal= total(bankbal) if hhbankacc==1
replace hhbankbal= 0 if hhbankbal==.
g hhbankbalpc= hhbankbal/hhsizer


//Define vulnerable group
*School feeding recipient (exclude top 3 hh deciles to match national)
g schoolfed= inrange(best_age_yrs, 7,18) & hhincpc_decile<=6		
bys hhid: egen hhschoolfed= total(schoolfed)


*Vulnerable group (include informal)
g vulnerable= 0
replace vulnerable= 1 if informal==1
replace vulnerable= 1 if schoolfed==1
replace vulnerable= 1 if emplstat==3 & informal!=1 & hhbankbalpc<=580
bys hhid: egen hhvulnerable= max(vulnerable)

foreach var in hhvulnerable vulnerable schoolfed hhschoolfed hhbankbalpc hhbankbal bankbal hhbankacc {
	assert `var'!=.
}


****************************************************************
*CAR OWNERSHIP (including bakkie or truck, not including motorcycle/scooter)
****************************************************************

gen car = 1 if ownveh == 1
replace car = 0 if ownveh == 2

* similar to bank balance variable, when restricting to adult questionnaire we get rid of most missing, but still 2.4m missing adults. 
tab car quest_typ [fw = fwgt], m

* hhold car dummy (can't get hhold count of cars as can't count individual cars)
by hhid: egen hhcar = max(car) 


* other relvenat vars
recode em1pay em1hrs (-9/-2=-3)
replace em1pay=0 if emplstat==0 | emplstat==1 |  emplstat==2
replace em1hrs=0 if emplstat==0 | emplstat==1 |  emplstat==2
****************************************************************
*WRAP UP
****************************************************************

keep  hhid female best_race best_edu urban hhsizer hhincome formal hhincomepc csg hhcsg hhcsg_income incchld_v totwage hhwage emplstat best_age_yrs hhincomepc em1deduif nogrant oap hhoap empltype hhremitt incdis  incfos  inccare  incaid  hhgovt  *bank* car hhcar nogrant hhgovt prov2011 written dedmed dedpen bsnsstax pid em1occ_isco_c em2occ_isco_c emsatc_isco_c emsothatc_isco_c emctype_isco_c emhtsk_isco_c em1prod_c em2prod_c emssect emsothsect emcsect em1pay em1hrs expenditure

keep if best_age_yrs>=15 

rename * LScat_*
ren LScat_hhid hhid
ren LScat_pid pid
rename LScat_em1pay LScon_em1pay
rename LScat_em1hrs LScon_em1hrs
rename LScat_incchld_v LScon_incchld_v
rename LScat_best_age_yrs LScon_best_age_yrs
rename LScat_hhsizer LScon_hhsizer
rename LScat_hhincome LScon_hhincome
rename LScat_hhwage LScon_hhwage
rename LScat_hhgovt LScon_hhgovt
rename LScat_hhremitt LScon_hhremitt
rename LScat_expenditure LScon_expenditure
rename LScat_totwage LScon_totwage
rename LScat_hhcsg_income LScon_hhcsg_income
rename LScat_hhincomepc LScon_hhincomepc
rename LScat_bankbal LScon_bankbal
rename LScat_hhbankbal LScon_hhbankbal
rename LScat_hhbankbalpc LScon_hhbankbalpc

mvencode LScat_*, mv(9999)

save "temp_lasso.dta", replace


